@@ -151,9 +151,9 @@ class FanboxExtractor(Extractor):
                 post["plan"] = plans[fee] = plan
         if self._meta_comments:
             if post.get("commentCount"):
-                post["comments"] = list(self._get_comment_data(post["id"]))
+                post["comments"] = self._get_comment_data(post["id"])
             else:
-                post["commentd"] = ()
+                post["comments"] = ()
 
         return content_body, post
 
@@ -208,12 +208,15 @@ class FanboxExtractor(Extractor):
                "?limit=10&postId=" + post_id)
 
         comments = []
-        while url:
-            url = text.ensure_http_scheme(url)
-            body = self.request_json(url, headers=self.headers)["body"]
-            data = body["commentList"]
-            comments.extend(data["items"])
-            url = data["nextUrl"]
+        try:
+            while url:
+                comlist = self.request_json(
+                    text.ensure_http_scheme(url), headers=self.headers,
+                )["body"]["commentList"]
+                comments.extend(comlist["items"])
+                url = comlist["nextUrl"]
+        except Exception as exc:
+            self.log.debug("comments: %s: %s", exc.__class__.__name__, exc)
         return comments
 
     def _get_urls_from_post(self, content_body, post):
@@ -340,7 +343,7 @@ class FanboxExtractor(Extractor):
             url = (f"https://docs.google.com/forms/d/e/"
                    f"{content_id}/viewform?usp=sf_link")
         else:
-            self.log.warning(f"service not recognized: {provider}")
+            self.log.warning("service not recognized: %s", provider)
 
         if url:
             final_post["embed"] = embed
@@ -355,7 +358,7 @@ class FanboxExtractor(Extractor):
 class FanboxCreatorExtractor(FanboxExtractor):
     """Extractor for a Fanbox creator's works"""
     subcategory = "creator"
-    pattern = rf"{USER_PATTERN}(?:/posts)?/?$"
+    pattern = USER_PATTERN + r"(?:/posts)?/?$"
     example = "https://USER.fanbox.cc/"
 
     def posts(self):
@@ -384,7 +387,7 @@ class FanboxCreatorExtractor(FanboxExtractor):
 class FanboxPostExtractor(FanboxExtractor):
     """Extractor for media from a single Fanbox post"""
     subcategory = "post"
-    pattern = rf"{USER_PATTERN}/posts/(\d+)"
+    pattern = USER_PATTERN + r"/posts/(\d+)"
     example = "https://USER.fanbox.cc/posts/12345"
 
     def posts(self):
@@ -394,7 +397,7 @@ class FanboxPostExtractor(FanboxExtractor):
 class FanboxHomeExtractor(FanboxExtractor):
     """Extractor for your Fanbox home feed"""
     subcategory = "home"
-    pattern = rf"{BASE_PATTERN}/?$"
+    pattern = BASE_PATTERN + r"/?$"
     example = "https://fanbox.cc/"
 
     def posts(self):
@@ -405,7 +408,7 @@ class FanboxHomeExtractor(FanboxExtractor):
 class FanboxSupportingExtractor(FanboxExtractor):
     """Extractor for your supported Fanbox users feed"""
     subcategory = "supporting"
-    pattern = rf"{BASE_PATTERN}/home/supporting"
+    pattern = BASE_PATTERN + r"/home/supporting"
     example = "https://fanbox.cc/home/supporting"
 
     def posts(self):
