@@ -9,7 +9,7 @@
 """Extractors for XenForo forums"""
 
 from .common import BaseExtractor, Message
-from .. import text, exception
+from .. import text, util, exception
 from ..cache import cache
 import binascii
 
@@ -38,7 +38,7 @@ class XenforoExtractor(BaseExtractor):
             r'|<div class="bb(?:Image|Media)Wrapper[^>]*?'
             r'data-src="([^"]+".*?) />'
             r'|(?:<a [^>]*?href="|<iframe [^>]*?src="|'
-            r'''onclick="loadMedia\(this, ')([^"']+)'''
+            r'''onclick="loadMedia\(this, ')([^"']+[^<]*?<)'''
             r')'
         ).findall
 
@@ -46,10 +46,10 @@ class XenforoExtractor(BaseExtractor):
         base = root if (pos := root.find("/", 8)) < 0 else root[:pos]
         for post in self.posts():
             urls = extract_urls(post["content"])
+            if "data-s9e-mediaembed-iframe=" in post["content"]:
+                self._extract_embeds(urls, post)
             if post["attachments"]:
-                for att in text.extract_iter(
-                        post["attachments"], "<li", "</li>"):
-                    urls.append((None, att[att.find('href="')+6:], None, None))
+                self._extract_attachments(urls, post)
 
             data = {"post": post}
             post["count"] = data["count"] = len(urls)
@@ -65,12 +65,19 @@ class XenforoExtractor(BaseExtractor):
                         continue
                     if ext[0] == "/":
                         if ext[1] == "/":
+                            if "'" in ext:
+                                ext = ext[:ext.find("'")]
                             ext = "https:" + ext
                         elif ext.startswith("/goto/link-confirmation?"):
                             params = text.parse_query(text.unescape(ext[24:]))
                             ext = binascii.a2b_base64(params["url"]).decode()
+                        elif ext.startswith("/redirect/"):
+                            ext = text.unescape(text.extr(
+                                ext, ">", "<").strip())
                         else:
                             continue
+                    elif '"' in ext:
+                        ext = ext[:ext.find('"')]
                     data["num"] += 1
                     data["num_external"] += 1
                     data["type"] = "external"
@@ -195,14 +202,14 @@ class XenforoExtractor(BaseExtractor):
             if cookie.domain.endswith(self.cookies_domain)
         }
 
-    def _pagination(self, base, pnum=None, callback=None):
+    def _pagination(self, base, pnum=None, callback=None, params=""):
         base = self.root + base
 
         if pnum is None:
-            url = base + "/"
+            url = f"{base}/{params}"
             pnum = 1
         else:
-            url = f"{base}/page-{pnum}"
+            url = f"{base}/page-{pnum}{params}"
             pnum = None
 
         page = self.request_page(url).text
@@ -214,7 +221,7 @@ class XenforoExtractor(BaseExtractor):
             if pnum is None or "pageNav-jump--next" not in page:
                 return
             pnum += 1
-            page = self.request_page(f"{base}/page-{pnum}").text
+            page = self.request_page(f"{base}/page-{pnum}{params}").text
 
     def _pagination_reverse(self, base, pnum=None, callback=None):
         base = self.root + base
@@ -255,12 +262,15 @@ class XenforoExtractor(BaseExtractor):
 
         post = {
             "author": extr('data-author="', '"'),
-            "id": extr('data-content="post-', '"'),
+            "id": (extr('data-content="post-', '"') or
+                   extr('data-content="profile-post-', '"')),
             "author_url": (extr('itemprop="url" content="', '"') or
                            extr('<a href="', '"')),
             "date": self.parse_datetime_iso(extr('datetime="', '"')),
-            "content": extr('class="message-body',
-                            '<div class="js-selectToQuote'),
+            "content": (extr('class="message-body',
+                             '<div class="js-selectToQuote') or
+                        extr('class="message-body',
+                             '</article>')),
             "attachments": extr('<section class="message-attachments">',
                                 '</section>'),
         }
@@ -328,6 +338,29 @@ class XenforoExtractor(BaseExtractor):
 
         return album
 
+    def _parse_profile(self, page):
+        user = self._extract_jsonld(page)
+        main = user["mainEntity"]
+        url = user.get("url") or main.get("@id") or ""
+        slug, _, id = url[url.rfind("/", 0, -1)+1:-1].rpartition(".")
+
+        self.kwdict["profile"] = profile = {
+            "id"    : main.get("identifier") or id,
+            "url"   : url,
+            "slug"  : text.unquote(slug),
+            "name"  : main.get("name"),
+            "avatar": main.get("image"),
+            "description": main.get("description"),
+            "date"  : self.parse_datetime_iso(user.get("dateCreated")),
+        }
+
+        stats = main.get("interactionStatistic")
+        if isinstance(stats, list):
+            profile["follows"] = stats[0]["userInteractionCount"]
+            profile["likes"] = stats[1]["userInteractionCount"]
+
+        return profile
+
     def _parse_author(self, author, data):
         data["author"] = author.get("name") or ""
         if url := author.get("url"):
@@ -340,6 +373,40 @@ class XenforoExtractor(BaseExtractor):
             data["author_id"] = data["author"][15:]
         return data
 
+    def _extract_attachments(self, urls, post):
+        find = text.re(r"(?s)\shref=[\"'](.+)").search
+        for att in text.extract_iter(post["attachments"], "<li", "</li>"):
+            urls.append((None, find(att)[1], None, None))
+
+    def _extract_embeds(self, urls, post):
+        for embed in text.extract_iter(
+                post["content"], "data-s9e-mediaembed-iframe='", "'"):
+            data = {}
+            key = None
+            for value in util.json_loads(embed):
+                if key is None:
+                    key = value
+                else:
+                    data[key] = value
+                    key = None
+
+            src = data.get("src")
+            if not src:
+                self.log.debug(data)
+                continue
+
+            type = data.get("data-s9e-mediaembed")
+            frag = src[src.find("#")+1:]
+            if type == "tiktok":
+                url = "https://www.tiktok.com/@/video/" + frag
+            elif type == "reddit":
+                url = "https://embed.reddit.com/r/" + frag
+            else:
+                self.log.warning("%s: Unsupported media embed type '%s'",
+                                 post["id"], type)
+                continue
+            urls.append((None, None, None, url))
+
     def _extract_media(self, url, file):
         media = {}
         name, _, media["id"] = file.rpartition(".")
@@ -449,7 +516,12 @@ class XenforoThreadExtractor(XenforoExtractor):
 
         if (order := self.config("order-posts")) and \
                 order[0] not in ("d", "r"):
-            pages = self._pagination(path, pnum)
+            params = "?order=reaction_score" if order[0] == "s" else ""
+            pages = self._pagination(path, pnum, params=params)
+            reverse = False
+        elif order == "reaction":
+            pages = self._pagination(
+                path, pnum, params="?order=reaction_score")
             reverse = False
         else:
             pages = self._pagination_reverse(path, pnum)
@@ -555,3 +627,34 @@ class XenforoMediaItemExtractor(XenforoExtractor):
                       self._extract_media)(url, self.groups[-1])
         yield Message.Directory, "", media
         yield Message.Url, url, media
+
+
+class XenforoProfileExtractor(XenforoExtractor):
+    subcategory = "profile"
+    directory_fmt = ("{category}", "Profiles", "{profile[name]}")
+    archive_fmt = "{id}"
+    pattern = (BASE_PATTERN + r"(/(?:index\.php\?)?"
+               r"members/[^/?#]+)(?:/page-(\d+))?")
+    example = "https://simpcity.cr/members/USER.123/"
+
+    def posts(self):
+        path = self.groups[-2]
+        pnum = self.groups[-1]
+
+        if (order := self.config("order-posts")) and \
+                order[0] in {"d", "r"}:
+            pages = self._pagination_reverse(path, pnum)
+            reverse = True
+        else:
+            pages = self._pagination(path, pnum)
+            reverse = False
+
+        for page in pages:
+            if "profile" not in self.kwdict:
+                self._parse_profile(page)
+            posts = text.extract_iter(page, "<article ", "<footer")
+            if reverse:
+                posts = list(posts)
+                posts.reverse()
+            for html in posts:
+                yield self._parse_post(html)
